# Generated by roxygen2: do not edit by hand

S3method(format,a5_cell)
S3method(is.na,a5_cell)
S3method(pillar::pillar_shaft,a5_cell)
S3method(vctrs::vec_proxy_compare,a5_cell)
S3method(vctrs::vec_proxy_order,a5_cell)
S3method(vctrs::vec_ptype_abbr,a5_cell)
S3method(vctrs::vec_ptype_full,a5_cell)
S3method(vec_cast,a5_cell.a5_cell)
S3method(vec_cast,a5_cell.character)
S3method(vec_cast,character.a5_cell)
S3method(vec_ptype2,a5_cell.a5_cell)
S3method(vec_ptype2,a5_cell.character)
S3method(vec_ptype2,character.a5_cell)
S3method(wk::wk_crs,a5_cell)
S3method(wk::wk_handle,a5_cell)
export(a5_cell)
export(a5_cell_area)
export(a5_cell_distance)
export(a5_cell_from_arrow)
export(a5_cell_to_arrow)
export(a5_cell_to_boundary)
export(a5_cell_to_children)
export(a5_cell_to_lonlat)
export(a5_cell_to_parent)
export(a5_compact)
export(a5_get_num_cells)
export(a5_get_num_children)
export(a5_get_res0_cells)
export(a5_get_resolution)
export(a5_get_threads)
export(a5_grid_disk)
export(a5_hex_to_u64)
export(a5_is_valid)
export(a5_linestring_to_cells)
export(a5_lonlat_to_cell)
export(a5_polygon_to_cells)
export(a5_set_threads)
export(a5_spherical_cap)
export(a5_u64_to_hex)
export(a5_uncompact)
export(as_a5_cell)
export(is_a5_cell)
importFrom(rlang,caller_env)
importFrom(vctrs,vec_cast)
importFrom(vctrs,vec_ptype2)
useDynLib(a5R, .registration = TRUE)
