% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compact.R
\name{a5_uncompact}
\alias{a5_uncompact}
\title{Uncompact a set of A5 cells to a target resolution}
\usage{
a5_uncompact(cells, resolution)
}
\arguments{
\item{cells}{An \link{a5_cell} vector.}

\item{resolution}{Integer scalar target resolution (0--30).}
}
\value{
An \link{a5_cell} vector of uncompacted cells.
}
\description{
Expands each cell to its descendants at the target resolution.
}
\examples{
cell <- a5_lonlat_to_cell(-3.19, 55.95, resolution = 5)
a5_uncompact(cell, resolution = 7)
}
\seealso{
\code{\link[=a5_compact]{a5_compact()}}
}
