% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/threads.R
\name{a5_set_threads}
\alias{a5_set_threads}
\alias{a5_get_threads}
\title{Set the number of threads used by a5R}
\usage{
a5_set_threads(n = 1L)

a5_get_threads()
}
\arguments{
\item{n}{Integer scalar. Number of threads. Must be >= 1.}
}
\value{
Invisibly returns the previous thread count.

Integer scalar.
}
\description{
Controls the number of threads used for parallel processing in vectorised
functions. Set to 1 (the default) for sequential processing with zero
overhead, or higher for parallel execution via rayon.
}
