% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hierarchy.R
\name{a5_cell_to_parent}
\alias{a5_cell_to_parent}
\title{Navigate to parent cell(s)}
\usage{
a5_cell_to_parent(cell, resolution = NULL)
}
\arguments{
\item{cell}{An \link{a5_cell} vector.}

\item{resolution}{Integer scalar target parent resolution, or \code{NULL} for
the immediate parent.}
}
\value{
An \link{a5_cell} vector of parent cells.
}
\description{
Returns the parent cell of each input cell. By default returns the
immediate parent (one resolution coarser). Optionally target a specific
coarser resolution.
}
\examples{
cell <- a5_lonlat_to_cell(-3.19, 55.95, resolution = 10)
a5_cell_to_parent(cell)
a5_cell_to_parent(cell, resolution = 5)
}
\seealso{
\code{\link[=a5_cell_to_children]{a5_cell_to_children()}}, \code{\link[=a5_get_resolution]{a5_get_resolution()}}
}
